@@ -67,13 +67,13 @@ class AnalysisForm(forms.Form):
     wordDuration = forms.BooleanField(initial=True,required=False,label='Word duration')
     segmentalDurations = forms.BooleanField(initial=True,required=False,label='Segmental duration')
     category = forms.CharField(label='Category source')
-    category.widget = forms.Select(choices=CAT_CHOICES)
+    category.widget = forms.CheckboxSelectMultiple(choices=CAT_CHOICES)
     frequency = forms.CharField(label='Frequency source')
-    frequency.widget = forms.Select(choices=FREQ_CHOICES)
+    frequency.widget = forms.CheckboxSelectMultiple(choices=FREQ_CHOICES)
     nd = forms.CharField(label='Neighbourhood density source')
-    nd.widget = forms.Select(choices=NEIGH_DEN_CHOICES)
+    nd.widget = forms.CheckboxSelectMultiple(choices=NEIGH_DEN_CHOICES)
     phonotactic = forms.CharField(label='Phonotactic probability source')
-    phonotactic.widget = forms.Select(choices=PHONO_PROB_CHOICES)
+    phonotactic.widget = forms.CheckboxSelectMultiple(choices=PHONO_PROB_CHOICES)
     gender = forms.BooleanField(initial=True,required=False,label='Gender')
     age = forms.BooleanField(initial=True,required=False,label='Age')
     globalSpeakingRate = forms.BooleanField(initial=True,required=False,label='Global speaking rate')
