@@ -104,7 +104,7 @@ def doBasicAnalysis(form):
         #    AnalyzeSpeaker.delay(s,form)
         #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
         #job.apply_async(link=consolidateResultFiles.s())
-        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), consolidateResultFiles.s())
+        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), consolidateResultFiles.s())()
         res.get()
 
 @task()
